@@ -6,7 +6,7 @@ use utf8;
 package Marlin;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.002003';
+our $VERSION   = '0.002004';
 
 use constant _ATTRS => qw( this parents roles attributes strict constructor modifiers );
 use Exporter::Tiny qw( mkopt _croak );
@@ -209,7 +209,8 @@ sub setup_steps {
 sub mark_inc {
 	my $me = shift;
 	
-	$INC{module_notional_filename($me->this)} //= __FILE__;
+	my $file = module_notional_filename($me->this);
+	$INC{$file} = __FILE__ unless defined $file;
 	
 	return $me;
 }
